#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['toxopy']

package_data = \
{'': ['*']}

install_requires = \
['pandas', 'dlcu']

setup(name='toxopy',
      version='0.1.5.1',
      description='Object-specific python package to run automated tasks in the Chase Lab.',
      author='fcatus',
      author_email='f.catus@pm.me',
      url='https://github.com/bchaselab/toxopy',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      python_requires='>=3.6',
     )
